==> skrooge-0.5.4.tar.bz2: skrooge-0.5.4/skrooge_operation/skgbookmarkboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGBOOKMARKBOARDWIDGET_H
#define SKGBOOKMARKBOARDWIDGET_H
/** @file
 * This file is Skrooge plugin for bookmark management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgbookmarkboardwidget.h"
#include "skgwidget.h"

/**
 * This file is Skrooge plugin for bank management
 */
class SKGBookmarkBoardWidget : public SKGWidget
{
        Q_OBJECT

public:
        /**
         * Default Constructor
         */
        SKGBookmarkBoardWidget (SKGDocument* iDocument );

        /**
         * Default Destructor
         */
        virtual ~SKGBookmarkBoardWidget();

private slots:
        void dataModified(const QString& iTableName, int iIdTransaction);
        void onOpen(const QString& iLink);

private:
        Q_DISABLE_COPY ( SKGBookmarkBoardWidget );

        Ui::skgbookmarkboardwidget ui;;
};

#endif // SKGBOOKMARKBOARDWIDGET_H

==> skrooge-0.7.2.tar.bz2: skrooge-0.7.2/skrooge_operation/skgbookmarkboardwidget.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGBOOKMARKBOARDWIDGET_H
#define SKGBOOKMARKBOARDWIDGET_H
/** @file
 * This file is Skrooge plugin for bookmark management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/
#include "ui_skgbookmarkboardwidget.h"
#include "skgwidget.h"

/**
 * This file is Skrooge plugin for bank management
 */
class SKGBookmarkBoardWidget : public SKGWidget
{
    Q_OBJECT

public:
    /**
     * Default Constructor
     */
    SKGBookmarkBoardWidget (SKGDocument* iDocument );

    /**
     * Default Destructor
     */
    virtual ~SKGBookmarkBoardWidget();

    /**
     * Get the current state
     * MUST BE OVERWRITTEN
     * @return a string containing all information needed to set the same state.
     * Could be an XML stream
     */
    virtual QString getState();

    /**
     * Set the current state
     * MUST BE OVERWRITTEN
     * @param iState must be interpreted to set the state of the widget
     */
    virtual void setState(const QString& iState);

private slots:
    void dataModified(const QString& iTableName, int iIdTransaction);
    void onOpen(const QString& iLink);

private:
    Q_DISABLE_COPY ( SKGBookmarkBoardWidget );

    Ui::skgbookmarkboardwidget ui;;
};

#endif // SKGBOOKMARKBOARDWIDGET_H
